@@ -1,21 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "localresourcecreator.h"
 
-#include <AkonadiCore/agentmanager.h>
-#include <AkonadiCore/agentinstancecreatejob.h>
 #include <AkonadiCore/ServerManager>
+#include <AkonadiCore/agentinstancecreatejob.h>
+#include <AkonadiCore/agentmanager.h>
 
 #include "maildirsettings.h"
 
 #include <Akonadi/Notes/NoteUtils>
 
 #include "noteshared_debug.h"
-#include <KLocalizedString>
 #include <AkonadiCore/resourcesynchronizationjob.h>
+#include <KLocalizedString>
 
 using namespace NoteShared;
 
@@ -50,7 +50,7 @@ void LocalResourceCreator::createInstance()
 {
     Akonadi::AgentType notesType = Akonadi::AgentManager::self()->type(akonadiNotesInstanceName());
 
-    auto *job = new Akonadi::AgentInstanceCreateJob(notesType);
+    auto job = new Akonadi::AgentInstanceCreateJob(notesType);
     connect(job, &Akonadi::AgentInstanceCreateJob::result, this, &LocalResourceCreator::slotInstanceCreated);
 
     job->start();
@@ -64,7 +64,7 @@ void LocalResourceCreator::slotInstanceCreated(KJob *job)
         return;
     }
 
-    auto *createJob = qobject_cast<Akonadi::AgentInstanceCreateJob *>(job);
+    auto createJob = qobject_cast<Akonadi::AgentInstanceCreateJob *>(job);
     Akonadi::AgentInstance instance = createJob->instance();
 
     instance.setName(i18nc("Default name for resource holding notes", "Local Notes"));
@@ -79,7 +79,7 @@ void LocalResourceCreator::slotInstanceCreated(KJob *job)
     }
     instance.reconfigure();
 
-    auto *syncJob = new Akonadi::ResourceSynchronizationJob(instance, this);
+    auto syncJob = new Akonadi::ResourceSynchronizationJob(instance, this);
     connect(syncJob, &Akonadi::ResourceSynchronizationJob::result, this, &LocalResourceCreator::slotSyncDone);
     syncJob->start();
 }
